@@ -1,5 +1,6 @@
 import re
-from typing import Iterable, Tuple, Optional
+from typing import Tuple, Optional
+from collections.abc import Iterable
 
 from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.exceptions import PureVirtualPathError, TestPathWithNonExistentFSPathError
@@ -82,7 +83,7 @@ class _ShebangScriptFiles(MatchRule):
                 yield p
 
     @property
-    def path_type(self) -> Optional[PathType]:
+    def path_type(self) -> PathType | None:
         return PathType.FILE
 
     def _full_pattern(self) -> str:
@@ -105,7 +106,7 @@ def builtin_mode_normalization_rules(
     dpkg_architecture_variables: DpkgArchitectureBuildProcessValuesTable,
     dctrl_bin: BinaryPackage,
     substitution: Substitution,
-) -> Iterable[Tuple[MatchRule, FileSystemMode]]:
+) -> Iterable[tuple[MatchRule, FileSystemMode]]:
     yield from (
         (
             MatchRule.from_path_or_glob(
