@@ -3,20 +3,18 @@ import dataclasses
 import inspect
 import sys
 from typing import (
-    Callable,
     TypeVar,
-    Sequence,
     Union,
     Dict,
     List,
     Optional,
-    AsyncIterator,
     Self,
     Generic,
     Protocol,
     TYPE_CHECKING,
     Literal,
 )
+from collections.abc import Callable, Sequence, AsyncIterator
 
 from debputy.commands.debputy_cmd.context import CommandContext
 from debputy.commands.debputy_cmd.output import _output_styling
@@ -28,12 +26,14 @@ try:
 except ImportError:
     pass
 
-from debputy.linting.lint_util import AsyncLinterImpl
+from debputy.linting.lint_util import AsyncLinterImpl, LintState
 from debputy.lsp.quickfixes import provide_standard_quickfixes_from_diagnostics_ls
 from debputy.lsp.text_util import on_save_trim_end_of_line_whitespace
 
 if TYPE_CHECKING:
     import lsprotocol.types as types
+
+    Reformatter = Callable[[LintState], Optional[Sequence[types.TextEdit]]]
 else:
     import debputy.lsprotocol.types as types
 
@@ -61,19 +61,19 @@ DiagnosticHandler = Callable[
         "DebputyLanguageServer",
         Union["types.DidOpenTextDocumentParams", "types.DidChangeTextDocumentParams"],
     ],
-    AsyncIterator[Optional[List[types.Diagnostic]]],
+    AsyncIterator[Optional[list[types.Diagnostic]]],
 ]
 
 
 @dataclasses.dataclass(slots=True)
 class LanguageDispatchTable(Generic[C]):
     language_id: str
-    basename_based_lookups: Dict[str, C] = dataclasses.field(default_factory=dict)
-    path_name_based_lookups: Dict[str, C] = dataclasses.field(default_factory=dict)
-    default_handler: Optional[C] = None
+    basename_based_lookups: dict[str, C] = dataclasses.field(default_factory=dict)
+    path_name_based_lookups: dict[str, C] = dataclasses.field(default_factory=dict)
+    default_handler: C | None = None
 
 
-class HandlerDispatchTable(Generic[C], Dict[str, LanguageDispatchTable[C]]):
+class HandlerDispatchTable(Generic[C], dict[str, LanguageDispatchTable[C]]):
     def __missing__(self, key: str) -> LanguageDispatchTable[C]:
         r = LanguageDispatchTable(key)
         self[key] = r
@@ -84,15 +84,19 @@ class DiagnosticHandlerProtocol(Protocol):
     async def __call__(
         self,
         ls: "DebputyLanguageServer",
-        params: Union[
-            types.DidOpenTextDocumentParams,
-            types.DidChangeTextDocumentParams,
-            types.DocumentDiagnosticParams,
-        ],
-    ) -> Union[List[types.Diagnostic], None]: ...
+        params: (
+            types.DidOpenTextDocumentParams
+            | types.DidChangeTextDocumentParams
+            | types.DocumentDiagnosticParams
+        ),
+    ) -> list[types.Diagnostic] | None: ...
 
 
-DIAGNOSTIC_HANDLERS: HandlerDispatchTable[DiagnosticHandlerProtocol] = (
+CLI_DIAGNOSTIC_HANDLERS: dict[str, AsyncLinterImpl] = {}
+CLI_FORMAT_FILE_HANDLERS: dict[str, "Reformatter"] = {}
+
+
+LSP_DIAGNOSTIC_HANDLERS: HandlerDispatchTable[DiagnosticHandlerProtocol] = (
     HandlerDispatchTable[DiagnosticHandlerProtocol]()
 )
 COMPLETER_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
@@ -101,7 +105,7 @@ CODE_ACTION_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
 FOLDING_RANGE_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
 SEMANTIC_TOKENS_FULL_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
 WILL_SAVE_WAIT_UNTIL_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
-FORMAT_FILE_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
+LSP_FORMAT_FILE_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
 TEXT_DOC_INLAY_HANDLERS: HandlerDispatchTable[C] = HandlerDispatchTable()
 _ALIAS_OF = {}
 
@@ -115,38 +119,46 @@ class BasenameMatchingRule:
 @dataclasses.dataclass(slots=True, frozen=True)
 class SecondaryLanguage:
     language_id: str
-    secondary_lookup: Optional[Literal["path-name", "basename"]] = None
+    secondary_lookup: Literal["path-name", "basename"] | None = None
 
 
 @dataclasses.dataclass(slots=True, frozen=True)
 class LanguageDispatchRule:
     primary_language_id: str
-    basename: Optional[str]
+    basename: str | None
     path_names: Sequence[str]
     secondary_language_ids: Sequence[SecondaryLanguage]
+    is_debsrc_packaging_file: bool
 
     @classmethod
     def new_rule(
         cls,
         primary_language_id: str,
-        basename: Optional[str],
-        path_names: Union[str, Sequence[str]],
-        secondary_language_ids: Sequence[Union[SecondaryLanguage, str]] = (),
+        basename: str | None,
+        path_names: str | Sequence[str],
+        secondary_language_ids: Sequence[SecondaryLanguage | str] = (),
     ) -> Self:
+        path_names_as_seq: Sequence[str] = (
+            (path_names,) if isinstance(path_names, str) else tuple(path_names)
+        )
+        is_debsrc_packaging_file = any(
+            pn.startswith("debian/") for pn in path_names_as_seq
+        )
         return LanguageDispatchRule(
             primary_language_id,
             basename,
-            (path_names,) if isinstance(path_names, str) else tuple(path_names),
+            path_names_as_seq,
             tuple(
                 SecondaryLanguage(l) if isinstance(l, str) else l
                 for l in secondary_language_ids
             ),
+            is_debsrc_packaging_file,
         )
 
 
 _STANDARD_HANDLERS = {
     types.TEXT_DOCUMENT_FORMATTING: (
-        FORMAT_FILE_HANDLERS,
+        LSP_FORMAT_FILE_HANDLERS,
         on_save_trim_end_of_line_whitespace,
     ),
     types.TEXT_DOCUMENT_CODE_ACTION: (
@@ -170,17 +182,21 @@ def lint_diagnostics(
 
         async def _lint_wrapper(
             ls: "DebputyLanguageServer",
-            params: Union[
-                types.DidOpenTextDocumentParams,
-                types.DidChangeTextDocumentParams,
-                types.DocumentDiagnosticParams,
-            ],
-        ) -> Optional[List[types.Diagnostic]]:
+            params: (
+                types.DidOpenTextDocumentParams
+                | types.DidChangeTextDocumentParams
+                | types.DocumentDiagnosticParams
+            ),
+        ) -> list[types.Diagnostic] | None:
             doc = ls.workspace.get_text_document(params.text_document.uri)
             lint_state = ls.lint_state(doc)
             return await lint_state.run_diagnostics(func)
 
-        _register_handler(file_format, DIAGNOSTIC_HANDLERS, _lint_wrapper)
+        _register_handler(file_format, LSP_DIAGNOSTIC_HANDLERS, _lint_wrapper)
+        if file_format.is_debsrc_packaging_file:
+            for path_name in file_format.path_names:
+                if path_name.startswith("debian/"):
+                    CLI_DIAGNOSTIC_HANDLERS[path_name] = func
 
         return func
 
@@ -212,7 +228,17 @@ def lsp_will_save_wait_until(file_format: LanguageDispatchRule) -> Callable[[C],
 
 
 def lsp_format_document(file_format: LanguageDispatchRule) -> Callable[[C], C]:
-    return _registering_wrapper(file_format, FORMAT_FILE_HANDLERS)
+    return _registering_wrapper(file_format, LSP_FORMAT_FILE_HANDLERS)
+
+
+def lsp_cli_reformat_document(file_format: LanguageDispatchRule) -> Callable[[C], C]:
+    def _wrapper(func: C) -> C:
+        for path_name in file_format.path_names:
+            if path_name.startswith("debian/"):
+                CLI_FORMAT_FILE_HANDLERS[path_name] = func
+        return func
+
+    return _wrapper
 
 
 def lsp_semantic_tokens_full(file_format: LanguageDispatchRule) -> Callable[[C], C]:
@@ -301,7 +327,7 @@ def _register_handler(
             secondary_table.default_handler = handler
 
 
-def ensure_lsp_features_are_loaded() -> None:
+def ensure_cli_lsp_features_are_loaded() -> None:
     # These imports are needed to force loading of the LSP files. The relevant registration
     # happens as a side effect of the imports.
     import debputy.lsp.languages as lsp_languages
@@ -315,10 +341,10 @@ def ensure_lsp_features_are_loaded() -> None:
 
 def describe_lsp_features(context: CommandContext) -> None:
     fo = _output_styling(context.parsed_args, sys.stdout)
-    ensure_lsp_features_are_loaded()
+    ensure_cli_lsp_features_are_loaded()
 
     feature_list = [
-        ("diagnostics (lint)", DIAGNOSTIC_HANDLERS),
+        ("diagnostics (lint)", LSP_DIAGNOSTIC_HANDLERS),
         ("code actions/quickfixes", CODE_ACTION_HANDLERS),
         ("completion suggestions", COMPLETER_HANDLERS),
         ("hover docs", HOVER_HANDLERS),
@@ -326,10 +352,10 @@ def describe_lsp_features(context: CommandContext) -> None:
         ("semantic tokens", SEMANTIC_TOKENS_FULL_HANDLERS),
         ("on-save handler", WILL_SAVE_WAIT_UNTIL_HANDLERS),
         ("inlay hint (doc)", TEXT_DOC_INLAY_HANDLERS),
-        ("format file handler", FORMAT_FILE_HANDLERS),
+        ("format file handler", LSP_FORMAT_FILE_HANDLERS),
     ]
     print("LSP language IDs and their features:")
-    all_ids = sorted(set(lid for _, t in feature_list for lid in t))
+    all_ids = sorted({lid for _, t in feature_list for lid in t})
     for lang_id in all_ids:
         if lang_id in _ALIAS_OF:
             continue
