@@ -15,7 +15,8 @@ from .locatable import (
 from debian._util import resolve_ref, _strI
 
 try:
-    from typing import Optional, cast, TYPE_CHECKING, Iterable, Union, Dict, Callable
+    from typing import Optional, cast, TYPE_CHECKING, Union, Dict
+    from collections.abc import Iterable, Callable
 except ImportError:
     # pylint: disable=unnecessary-lambda-assignment
     TYPE_CHECKING = False
@@ -65,7 +66,7 @@ _RE_COMMA_SEPARATED_WORD_LIST = re.compile(
     # From here it is "optional space, maybe a word and then optional space" again.  One reason why
     # all of it is optional is to gracefully cope with trailing commas.
     (?P<space_before_word>\s*)
-    (?P<word> [^,\s] (?: [^,]*[^,\s])? )?    # "Words" can contain spaces for comma separated list.
+    (?P<word> [^,\s] (?: [^,]*[^,\s])? )?    # "Words" can contain spaces for comma-separated list.
                                              # But surrounding whitespace is ignored
     (?P<space_after_word>\s*)
 """,
