@@ -1,7 +1,8 @@
 import json
 import os
 import subprocess
-from typing import Optional, Sequence, List, Tuple
+from typing import Optional, List, Tuple
+from collections.abc import Sequence
 
 from debputy import DEBPUTY_ROOT_DIR
 from debputy.commands.debputy_cmd.context import CommandContext
@@ -32,7 +33,7 @@ def _serialize_intermediate_manifest(members: IntermediateManifest) -> str:
 def determine_assembly_method(
     package: str,
     intermediate_manifest: IntermediateManifest,
-) -> Tuple[bool, bool, List[str]]:
+) -> tuple[bool, bool, list[str]]:
     paths_needing_root = (
         tm for tm in intermediate_manifest if tm.owner != "root" or tm.group != "root"
     )
@@ -171,11 +172,11 @@ def _assemble_deb(
     mtime: int,
     control_output_fs_path: str,
     output_path: str,
-    upstream_args: Optional[List[str]],
+    upstream_args: list[str] | None,
     is_udeb: bool = False,
     use_fallback_assembly: bool = False,
     needs_root: bool = False,
-    gain_root_cmd: Optional[Sequence[str]] = None,
+    gain_root_cmd: Sequence[str] | None = None,
     *,
     debug_materialization: bool = False,
 ) -> None:
@@ -184,7 +185,7 @@ def _assemble_deb(
         scratch_root_dir, "materialization-dirs", package
     )
     ensure_dir(os.path.dirname(materialization_dir))
-    materialize_cmd: List[str] = []
+    materialize_cmd: list[str] = []
     assert not use_fallback_assembly or not gain_root_cmd
     if needs_root and gain_root_cmd:
         # Only use the gain_root_cmd if we absolutely need it.
